aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorCary Clark <caryclark@skia.org>2018-11-09 16:04:58 -0500
committerSkia Commit-Bot <skia-commit-bot@chromium.org>2018-11-09 21:33:54 +0000
commit777eede7800ea060c94ce7e4a426769eda15ca2d (patch)
tree147c6b8621f3231225879f041e9cdaa3e138a54f /include
parent540d57181fb3dcb040b34819ed1cb92897c5e36c (diff)
downloadskqp-777eede7800ea060c94ce7e4a426769eda15ca2d.tar.gz
fix bookmaker
Remove references to old SkPaint::Hinting. Also fix bug recently introduced that made unlinkable words use the last link found. TBR=reed@google.com Docs-Preview: https://skia.org/?cl=170266 Bug: skia: Change-Id: I8b83bcb479bd3f79699a1c74818a817190fd42a5 Reviewed-on: https://skia-review.googlesource.com/c/170266 Commit-Queue: Cary Clark <caryclark@skia.org> Auto-Submit: Cary Clark <caryclark@skia.org> Reviewed-by: Cary Clark <caryclark@skia.org>
Diffstat (limited to 'include')
-rw-r--r--include/core/SkPaint.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/core/SkPaint.h b/include/core/SkPaint.h
index 251fdaefa4..66bc83cac7 100644
--- a/include/core/SkPaint.h
+++ b/include/core/SkPaint.h
@@ -355,9 +355,9 @@ public:
*/
void setEmbeddedBitmapText(bool useEmbeddedBitmapText);
- /** Returns true if SkPaint::Hinting is set to kNormal_Hinting or kFull_Hinting, and if
- platform uses FreeType as the font manager. If true, instructs
- the font manager to always hint glyphs.
+ /** Returns true if SkPaint::Hinting is set to SkFontHinting::kNormal or
+ SkFontHinting::kFull, and if platform uses FreeType as the font manager.
+ If true, instructs the font manager to always hint glyphs.
Equivalent to getFlags() masked with kAutoHinting_Flag.
@@ -368,10 +368,10 @@ public:
}
/** Sets whether to always hint glyphs.
- If SkPaint::Hinting is set to kNormal_Hinting or kFull_Hinting and useAutohinter is set,
- instructs the font manager to always hint glyphs.
- auto-hinting has no effect if SkPaint::Hinting is set to kNo_Hinting or
- kSlight_Hinting.
+ If SkPaint::Hinting is set to SkFontHinting::kNormal or SkFontHinting::kFull
+ and useAutohinter is set, instructs the font manager to always hint glyphs.
+ auto-hinting has no effect if SkPaint::Hinting is set to SkFontHinting::kNone or
+ SkFontHinting::kSlight.
Only affects platforms that use FreeType as the font manager.